@@ -20,3 +20,6 @@ class TestPitrading(unittest.TestCase):
 
     def test_000_something(self):
         """Test something."""
+        # Holidays.range_exp("20150101", "20280101")
+        # Holidays.range_exp("20050101", "20180101")
+        Holidays.range_exp("20150101", "20180101")
